# 2022-07-07 - Distribution Scheduler

Deployment of the `DistributionScheduler`, which can be used to schedule token distributions to gauges in advance, making operations simpler.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`DistributionScheduler` artifact](./artifact/DistributionScheduler.json)
